Repository: mesos
Updated Branches:
  refs/heads/master 212bb114f -> c4cec59f0


Fixed the multi taskgroup shared pid ns test due to slowness.

Review: https://reviews.apache.org/r/64171/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/6c1ee317
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/6c1ee317
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/6c1ee317

Branch: refs/heads/master
Commit: 6c1ee3177543c1954e0893353d5b55500bab3c37
Parents: 212bb11
Author: Gilbert Song <songzihao1...@gmail.com>
Authored: Wed Nov 29 17:39:37 2017 -0800
Committer: Gilbert Song <songzihao1...@gmail.com>
Committed: Wed Nov 29 17:39:37 2017 -0800

----------------------------------------------------------------------
 src/tests/default_executor_tests.cpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/6c1ee317/src/tests/default_executor_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/default_executor_tests.cpp 
b/src/tests/default_executor_tests.cpp
index 04d9e1b..0b80d4a 100644
--- a/src/tests/default_executor_tests.cpp
+++ b/src/tests/default_executor_tests.cpp
@@ -1851,7 +1851,7 @@ TEST_P(DefaultExecutorTest, 
ROOT_MultiTaskgroupSharePidNamespace)
       taskInfo2.task_id().value(),
       "ns");
 
   // Wait up to 5 seconds for each of the two tasks to
   // write its pid namespace inode into its sandbox.
   Duration waited = Duration::zero();
   do {
@@ -1861,7 +1861,7 @@ TEST_P(DefaultExecutorTest, 
ROOT_MultiTaskgroupSharePidNamespace)
 
     os::sleep(Seconds(1));
     waited += Seconds(1);
-  } while (waited < Seconds(5));
+  } while (waited < Seconds(10));
 
   EXPECT_TRUE(os::exists(pidNamespacePath1));
   EXPECT_TRUE(os::exists(pidNamespacePath2));
@@ -1851,7 +1851,7 @@ TEST_P(DefaultExecutorTest, 
       "ns");
 
-  // Wait up to 5 seconds for each of the two tasks to
+  // Wait up to 10 seconds for each of the two tasks to
   // write its pid namespace inode into its sandbox.
   Duration waited = Duration::zero();

Reply via email to